OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"Config\" مۇندەرىجىسىگە يازغىلى بولمايدۇ!",
    "This can usually be fixed by giving the web server write access to the config directory." : "بۇنى ئادەتتە تور مۇلازىمېتىرىغا مۇندەرىجە مۇندەرىجىسىگە يېزىش ھوقۇقى بېرىش ئارقىلىق ئوڭشىغىلى بولىدۇ.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "ئەمما ، ئەگەر config.php ھۆججىتىنى پەقەت ئوقۇشنىلا ئويلىسىڭىز ، ئۇنىڭدا «config_is_read_only» تاللانمىسىنى توغرىلاڭ.",
    "See %s" : "%s گە قاراڭ",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "قوللىنىشچان %1$s ھازىر يوق ياكى بۇ مۇلازىمېتىر بىلەن ماس كەلمەيدىغان نەشرى بار. ئەپلەر مۇندەرىجىسىنى تەكشۈرۈپ بېقىڭ.",
    "Sample configuration detected" : "ئۈلگە سەپلىمىسى بايقالدى",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "ئەۋرىشكە سەپلىمىسىنىڭ كۆچۈرۈلگەنلىكى ئېنىقلاندى. بۇ قاچىلاشنى بۇزۇۋېتەلەيدۇ ۋە قوللىمايدۇ. Config.php دا ئۆزگەرتىش ئېلىپ بېرىشتىن بۇرۇن ھۆججەتلەرنى ئوقۇڭ",
    "The page could not be found on the server." : "بۇ بەتنى مۇلازىمېتىردىن تاپقىلى بولمايدۇ.",
    "%s email verification" : "%s ئېلېكترونلۇق خەت دەلىللەش",
    "Email verification" : "ئېلېكترونلۇق خەت دەلىللەش",
    "Click the following button to confirm your email." : "ئېلېكترونلۇق خەتنى جەزملەشتۈرۈش ئۈچۈن تۆۋەندىكى كۇنۇپكىنى بېسىڭ.",
    "Click the following link to confirm your email." : "ئېلېكترونلۇق خەتنى جەزملەشتۈرۈش ئۈچۈن تۆۋەندىكى ئۇلانمىنى چېكىڭ.",
    "Confirm your email" : "ئېلېكترونلۇق خەتنى جەزملەشتۈرۈڭ",
    "Other activities" : "باشقا پائالىيەتلەر",
    "%1$s and %2$s" : "%1$s ھەمدە %2$s",
    "%1$s, %2$s and %3$s" : "%1$s ۋە %2$s ھەمدە %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s، %2$s، %3$s، ھەمدە %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s، %2$s، %3$s، %4$s ھەمدە %5$s",
    "Education bundle" : "مائارىپ باغچىسى",
    "Enterprise bundle" : "كارخانا توپلىمى",
    "Groupware bundle" : "گۇرۇپپا يۇمشاق دېتاللىرى",
    "Hub bundle" : "Hub توپلام",
    "Public sector bundle" : "ئاممىۋى تارماقلار توپلىمى",
    "Social sharing bundle" : "ئىجتىمائىي ئورتاقلىشىش",
    "PHP %s or higher is required." : "%sPHP ياكى ئۇنىڭدىن يۇقىرى تەلەپ قىلىنىدۇ.",
    "PHP with a version lower than %s is required." : "نەشرى %s دىن تۆۋەن بولغان PHP تەلەپ قىلىنىدۇ.",
    "%sbit or higher PHP required." : "%s بىتتىن ياكى ئۇنىڭدىن يۇقىرى PHP تەلەپ قىلىنىدۇ.",
    "The following architectures are supported: %s" : "تۆۋەندىكى قۇرۇلمىلارنى قوللايدۇ:%s",
    "The following databases are supported: %s" : "تۆۋەندىكى سانداننى قوللايدۇ:%s",
    "The command line tool %s could not be found" : "بۇيرۇق قۇرى قورالى %s تېپىلمىدى",
    "The library %s is not available." : "كۇتۇپخانا %s نى ئىشلەتكىلى بولمايدۇ.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%2$s دىن يۇقىرى نەشرى بار كۇتۇپخانا %1$s تەلەپ قىلىنىدۇ - ئىشلەتكىلى بولىدىغان نۇسخىسى %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "%2$s دىن تۆۋەن نەشرى بار كۇتۇپخانا %1$s تەلەپ قىلىنىدۇ - ئىشلەتكىلى بولىدىغان نۇسخىسى %3$s.",
    "The following platforms are supported: %s" : "تۆۋەندىكى سۇپىلارنى قوللايدۇ: %s",
    "Server version %s or higher is required." : "مۇلازىمېتىرنىڭ %s ياكى ئۇنىڭدىن يۇقىرى نەشرى تەلەپ قىلىنىدۇ.",
    "Server version %s or lower is required." : "مۇلازىمېتىرنىڭ %s ياكى ئۇنىڭدىن تۆۋەن نەشرى تەلەپ قىلىنىدۇ.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "ھېساباتقا كىرگەن چوقۇم باشقۇرغۇچى ، تارماق باشقۇرغۇچى بولۇشى ياكى بۇ تەڭشەكنى زىيارەت قىلىش ھوقۇقى بولۇشى كېرەك",
    "Your current IP address doesn't allow you to perform admin actions" : "نۆۋەتتىكى IP ئادرېسىڭىز باشقۇرۇش ھەرىكىتىنى ئىجرا قىلىشقا يول قويمايدۇ",
    "Logged in account must be an admin or sub admin" : "ھېساباتقا كىرگەن چوقۇم باشقۇرغۇچى ياكى تارماق باشقۇرغۇچى بولۇشى كېرەك",
    "Logged in account must be an admin" : "ھېساباتقا كىرگەن چوقۇم باشقۇرغۇچى بولۇشى كېرەك",
    "Wiping of device %s has started" : "ئۈسكۈنىنىڭ %s نى ئۆچۈرۈش باشلاندى",
    "Wiping of device »%s« has started" : "ئۈسكۈنىنى سۈرتۈش »%s« باشلاندى",
    "»%s« started remote wipe" : "»%s« يىراقتىن سۈرتۈشنى باشلىدى",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "ئۈسكۈنە ياكى قوللىنىشچان پروگرامما »%s« يىراقتىن سۈرتۈش جەريانىنى باشلىدى. بۇ جەريان تاماملانغاندىن كېيىن يەنە بىر ئېلېكترونلۇق خەت تاپشۇرۇۋالىسىز",
    "Wiping of device %s has finished" : "ئۈسكۈنىنىڭ %s نى سۈرتۈش تاماملاندى",
    "Wiping of device »%s« has finished" : "ئۈسكۈنىنى سۈرتۈش »%s« تاماملاندى",
    "»%s« finished remote wipe" : "»%s« يىراقتىن سۈرتۈش",
    "Device or application »%s« has finished the remote wipe process." : "ئۈسكۈنە ياكى قوللىنىشچان پروگرامما »%s« يىراقتىن سۈرتۈش جەريانىنى تاماملىدى.",
    "Remote wipe started" : "يىراقتىن سۈرتۈش باشلاندى",
    "A remote wipe was started on device %s" : "%s ئۈسكۈنىدە يىراقتىن سۈرتۈش باشلاندى",
    "Remote wipe finished" : "يىراقتىن سۈرتۈش تاماملاندى",
    "The remote wipe on %s has finished" : "%s دىكى يىراقتىن سۈرتۈش تاماملاندى",
    "Authentication" : "دەلىللەش",
    "Unknown filetype" : "نامەلۇم ھۆججەت شەكلى",
    "Invalid image" : "ئىناۋەتسىز رەسىم",
    "Avatar image is not square" : "باش سۈرىتى چاسا ئەمەس",
    "Files" : "ھۆججەتلەر",
    "View profile" : "ئارخىپنى كۆرۈڭ",
    "same time" : "ئوخشاش ۋاقىت",
    "_%nh_::_%nh_" : ["%nسائەت","%nسائەت"],
    "_%nm_::_%nm_" : ["%nمىنۇت","%nمىنۇت"],
    "%s ahead" : "%s ئالىدىدا",
    "%s behind" : "%s كەينىدە",
    "Local time: %s" : "يەرلىك ۋاقىت:%s",
    "today" : "بۈگۈن",
    "tomorrow" : "ئەتە",
    "yesterday" : "تۈنۈگۈن",
    "_in %n day_::_in %n days_" : ["%n كۈندە","%n كۈندە"],
    "_%n day ago_::_%n days ago_" : ["%n كۈن ئىلگىرى","%n كۈن ئىلگىرى"],
    "next month" : "كېلەر ئاي",
    "last month" : "ئالدىنقى ئاي",
    "_in %n month_::_in %n months_" : ["%n ئايدا","%n ئايدا"],
    "_%n month ago_::_%n months ago_" : ["%n ئاي ئىلگىرى","%n ئاي ئىلگىرى"],
    "next year" : "كېلەر يىلى",
    "last year" : "ئۆتكەن يىلى",
    "_in %n year_::_in %n years_" : ["%n يىلدا","%n يىلدا"],
    "_%n year ago_::_%n years ago_" : ["%n يىل ئىلگىرى","%n يىل ئىلگىرى"],
    "_in %n hour_::_in %n hours_" : ["%n سائەتتە","%n سائەتتە"],
    "_%n hour ago_::_%n hours ago_" : ["%n سائەت ئىلگىرى","%n سائەت ئىلگىرى"],
    "_in %n minute_::_in %n minutes_" : ["%n مىنۇتتا","%n مىنۇتتا"],
    "_%n minute ago_::_%n minutes ago_" : ["%n مىنۇت ئىلگىرى","%n مىنۇت ئىلگىرى"],
    "in a few seconds" : "بىر نەچچە سېكۇنت ئىچىدە",
    "seconds ago" : "سېكۇنت بۇرۇن",
    "Empty file" : "بوش ھۆججەت",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "كىملىك بىلەن مودۇل:%s مەۋجۇت ئەمەس. ئۇنى ئەپ تەڭشىكىڭىزدە قوزغىتىڭ ياكى باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "No file conversion providers available" : "ھۆججەت ئايلاندۇرۇش مۇلازىمىتى يوق",
    "File is too large to convert" : "ھۆججەتنى ئايلاندۇرۇشقا بەك چوڭ",
    "Destination does not match conversion extension" : "مەنزىل ئۆزگەرتىش كېڭەيتىلمىسىگە ماس كەلمەيدۇ",
    "Could not convert file" : "ھۆججەتنى ئايلاندۇرغىلى بولمىدى",
    "Destination does not exist" : "مەنزىل مەۋجۇت ئەمەس",
    "Destination is not creatable" : "مەنزىلنى يارىتىشقا بولمايدۇ",
    "Dot files are not allowed" : "چېكىتلىك ھۆججەتلەرگە رۇخسەت قىلىنمايدۇ",
    "%1$s (renamed)" : "%1$s (قايتا ئسىملاندى)",
    "renamed file" : "قايتا ئىسىملانغان ھۆججەت",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" چەكلەنگەن ھۆججەت ياكى ھۆججەت قىسقۇچنىڭ ئىسمى.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" ھۆججەت ياكى ھۆججەت قىسقۇچ نامىنىڭ چەكلەنگەن ئالدى قوشۇلغۇچىسى.",
    "\"%1$s\" is not allowed inside a file or folder name." : "ھۆججەت ياكى ھۆججەت قىسقۇچنىڭ ئىچىدە \"%1$s\" رۇخسەت قىلىنمايدۇ.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" چەكلەنگەن ھۆججەت تىپى.",
    "Filenames must not end with \"%1$s\"." : "ھۆججەت ئىسمى «%1$s» بىلەن ئاخىرلاشماسلىقى كېرەك.",
    "Invalid parent path" : "ئاتا-ئانىلار يولى ئىناۋەتسىز",
    "File already exists" : "ھۆججەت مەۋجۇت",
    "Invalid path" : "ئىناۋەتسىز يول",
    "Failed to create file from template" : "قېلىپتىن ھۆججەت قۇرالمىدى",
    "Templates" : "قېلىپلار",
    "Storage %s cannot be moved" : "بوشلۇق %s نى يۆتكىگىلى بولمايدۇ",
    "Moving a share (%s) into a shared folder is not allowed" : "ئورتاقلىشىشنى (%s) ئورتاقلىشىش قىسقۇچقا يۆتكەشكە يول قويۇلمايدۇ",
    "Moving a storage (%s) into a shared folder is not allowed" : "ساقلىغۇچنى (%s) ئورتاق قىسقۇچقا يۆتكەشكە يول قويۇلمايدۇ",
    "Moving a share (%s) into another share (%s) is not allowed" : "بىر پاينى (%s) باشقا بىر پايغا (%s) يۆتكەشكە يول قويۇلمايدۇ",
    "Moving a share (%s) into another storage (%s) is not allowed" : "بىر ئورتاقلىشىشنى (%s) باشقا ساقلىغۇچقا (%s) يۆتكەشكە يول قويۇلمايدۇ",
    "Moving a storage (%s) into a share (%s) is not allowed" : "ساقلاش بوشلۇقىنى (%s) ئورتاقلىشىش بوشلۇقىغا (%s) يۆتكەشكە يول قويۇلمايدۇ",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "بىر ساقلىغۇچنى (%s) باشقا ساقلىغۇچقا (%s) يۆتكەشكە يول قويۇلمايدۇ",
    "Path contains invalid segments" : "يول ئىناۋەتسىز بۆلەكلەرنى ئۆز ئىچىگە ئالىدۇ",
    "Filename is a reserved word" : "ھۆججەت ئىسمى زاپاس سۆز",
    "Filename contains at least one invalid character" : "ھۆججەت ئىسمى كەم دېگەندە بىر ئىناۋەتسىز ھەرپنى ئۆز ئىچىگە ئالىدۇ",
    "Filename is too long" : "ھۆججەت ئىسمى بەك ئۇزۇن",
    "Empty filename is not allowed" : "قۇرۇق ھۆججەت ئىسمى رۇخسەت قىلىنمايدۇ",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appinfo ھۆججىتىنى ئوقۇغىلى بولمىغاچقا ، «%s» نى قاچىلىغىلى بولمايدۇ.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "مۇلازىمېتىرنىڭ بۇ نەشرىگە ماس كەلمىگەچكە «%s» دېتالىنى قاچىلىغىلى بولمايدۇ.",
    "__language_name__" : "ئۇيغۇرچە",
    "This is an automatically sent email, please do not reply." : "بۇ ئاپتوماتىك ئەۋەتىلگەن ئېلېكترونلۇق خەت ، جاۋاب قايتۇرماڭ.",
    "Help & privacy" : "ياردەم ۋە مەخپىيەتلىك",
    "Appearance and accessibility" : "تاشقى كۆرۈنۈشى ۋە قولايلىقلىقى",
    "Apps" : "ئەپلەر",
    "Personal settings" : "شەخسىي تەڭشەكلەر",
    "Administration settings" : "باشقۇرۇش تەڭشەكلىرى",
    "Settings" : "تەڭشەكلەر",
    "Log out" : "تىزىمدىن چىق",
    "Accounts" : "ھېسابات",
    "Bluesky" : "Bluesky",
    "View %s on Bluesky" : "%s نى Bluesky كۆرۈڭ",
    "Email" : "تورخەت",
    "Mail %s" : "خەت %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Feediverse دىكى %s نى كۆرۈڭ",
    "Phone" : "تېلېفون",
    "Call %s" : "تېلېفون %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Twitter دىكى %s نى كۆرۈڭ",
    "Website" : "تور بېكەت",
    "Visit %s" : "%s نى زىيارەت قىلىڭ",
    "Address" : "ئادرېس",
    "Profile picture" : "ئارخىپ رەسىمى",
    "About" : "ھەققىدە",
    "Display name" : "كۆرسىتىش ئىسمى",
    "Headline" : "ماۋزۇ",
    "Organization" : "ئورگان",
    "Role" : "رولى",
    "Pronouns" : "ئاتىلىشى",
    "Unknown account" : "نامەلۇم ھېسابات",
    "Additional settings" : "قوشۇمچە تەڭشەكلەر",
    "Enter the database Login and name for %s" : "ساندانغا كىرىڭ ۋە %s نىڭ ئىسمى",
    "Enter the database Login for %s" : "ساندانغا كىرىڭ %s",
    "Enter the database name for %s" : "%s نىڭ ساندان نامىنى كىرگۈزۈڭ",
    "You cannot use dots in the database name %s" : "%s ساندان نامىدا چېكىتلەرنى ئىشلىتەلمەيسىز",
    "MySQL Login and/or password not valid" : "MySQL كىرىش ۋە / ياكى پارول ئىناۋەتلىك ئەمەس",
    "You need to enter details of an existing account." : "مەۋجۇت ھېساباتنىڭ تەپسىلاتلىرىنى كىرگۈزۈشىڭىز كېرەك.",
    "Oracle connection could not be established" : "Oracle ئۇلىنىشى قۇرۇلمىدى",
    "Oracle Login and/or password not valid" : "Oracle كىرىش ۋە / ياكى پارول ئىناۋەتلىك ئەمەس",
    "PostgreSQL Login and/or password not valid" : "PostgreSQL كىرىش ۋە / ياكى پارول ئىناۋەتلىك ئەمەس",
    "macOS is not supported and %s will not work properly on this platform." : "MacOS نى قوللىمايدۇ، %s بۇ سۇپادا نورمال ئىشلىمەيدۇ.",
    "For the best results, please consider using a GNU/Linux server instead." : "ئەڭ ياخشى ئۈنۈمگە ئېرىشىش ئۈچۈن ، ئۇنىڭ ئورنىغا GNU / Linux مۇلازىمېتىرىنى ئىشلىتىشنى ئويلىشىڭ.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "قارىغاندا بۇ %s مىسالى 32 بىتلىق PHP مۇھىتىدا ئىجرا بولۇۋاتقاندەك ، open_basedir php.ini دا تەڭشەلگەن. بۇ 4 GB دىن يۇقىرى ھۆججەتلەردە مەسىلە كۆرۈلىدۇ ۋە ئۈمىدسىزلىنىدۇ.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Php.ini دىكى open_basedir تەڭشىكىنى ئېلىۋېتىڭ ياكى 64 بىتلىق PHP غا ئالماشتۇرۇڭ.",
    "Set an admin Login." : "باشقۇرغۇچى كىرىش.",
    "Set an admin password." : "باشقۇرغۇچى پارولى بەلگىلەڭ.",
    "Cannot create or write into the data directory %s" : "%s سانلىق مەلۇمات مۇندەرىجىسىگە قۇرغىلى ياكى يازغىلى بولمايدۇ",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "ئارقا زاپاس %s نى ئورتاق ئىشلىتىش چوقۇم OCP \\ Share_Backend كۆرۈنمە يۈزىنى ئىجرا قىلىشى كېرەك",
    "Sharing backend %s not found" : "ئورتاقلىشىش %s تېپىلمىدى",
    "Sharing backend for %s not found" : "%s ئۈچۈن ئارقا زاپاسلاش تېپىلمىدى",
    "%1$s shared %2$s with you" : "%1$s سىز بىلەن %2$s نى ئورتاقلاشتى",
    "Open %s" : "%s نى ئېچىڭ",
    "%1$s via %2$s" : "%1$s ئارقىلىق %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s بولسا %2$sنى سىز بىلەن ئورتاقلاشتى ۋە قوشماقچى:",
    "%1$s shared %2$s with you and wants to add" : "%1$s بولسا %2$s نى سىز بىلەن ئورتاقلاشتى ۋە قوشماقچى",
    "%s added a note to a file shared with you" : "%sسىز بىلەن ئورتاقلاشقان ھۆججەتكە خاتىرە قوشتى",
    "Passwords are enforced for link and mail shares" : "ئۇلىنىش ۋە خەت ئورتاقلىشىش ئۈچۈن پارول ئىجرا قىلىنىدۇ",
    "Share recipient is not a valid user" : "ھەمبەھىر تاپشۇرۇۋالغۇچى ئىناۋەتلىك ئىشلەتكۈچى ئەمەس",
    "Share recipient is not a valid group" : "ھەمبەھىر قوبۇل قىلغۇچى ئۈنۈملۈك گۇرۇپپا ئەمەس",
    "Share recipient should be empty" : "ھەمبەھىر تاپشۇرۇۋالغۇچى قۇرۇق بولۇشى كېرەك",
    "Share recipient should not be empty" : "ھەمبەھىر تاپشۇرۇۋالغۇچى بوش قالماسلىقى كېرەك",
    "Share recipient is not a valid circle" : "ھەمبەھىر قوبۇل قىلغۇچى ئۈنۈملۈك چەمبىرەك ئەمەس",
    "Unknown share type" : "نامەلۇم ئورتاقلىشىش تىپى",
    "Share initiator must be set" : "ھەمبەھىرلىگۈچى چوقۇم بېكىتىلىشى كېرەك",
    "Cannot share with yourself" : "ئۆزىڭىز بىلەن ئورتاقلىشالمايدۇ",
    "Shared path must be set" : "ئورتاق يول بەلگىلەش كېرەك",
    "Shared path must be either a file or a folder" : "ئورتاق يول چوقۇم ھۆججەت ياكى ھۆججەت قىسقۇچ بولۇشى كېرەك",
    "You cannot share your root folder" : "يىلتىز قىسقۇچنى ئورتاقلىشالمايسىز",
    "You are not allowed to share %s" : "%s نى ئورتاقلىشىڭىزغا رۇخسەت قىلىنمايدۇ",
    "Valid permissions are required for sharing" : "ئورتاقلىشىش ئۈچۈن ئىناۋەتلىك ئىجازەت تەلەپ قىلىنىدۇ",
    "File shares cannot have create or delete permissions" : "ھۆججەت ئورتاقلىشىش قۇرۇش ياكى ئۆچۈرۈش ھوقۇقىغا ئىگە بولمايدۇ",
    "Cannot increase permissions of %s" : "%s نىڭ ئىجازەتنامىسىنى ئاشۇرغىلى بولمايدۇ",
    "Shares need at least read permissions" : "پايلار ھېچ بولمىغاندا ئوقۇش ئىجازەتنامىسىگە موھتاج",
    "Files cannot be shared with delete permissions" : "ھۆججەتلەرنى ئۆچۈرۈش ھوقۇقى بىلەن ئورتاقلىشىشقا بولمايدۇ",
    "Files cannot be shared with create permissions" : "ھۆججەتلەرنى قۇرۇش ئىجازەتنامىسى بىلەن ئورتاقلىشىشقا بولمايدۇ",
    "Expiration date is in the past" : "مۇددىتى توشقان",
    "Expiration date is enforced" : "مۇددىتى توشقان",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["كەلگۈسىدىكى مۇددىتى %n كۈندىن ئېشىپ كەتمەسلىكى كېرەك","كەلگۈسىدىكى مۇددىتى %n كۈندىن ئېشىپ كەتمەسلىكى كېرەك"],
    "Sharing is only allowed with group members" : "ئورتاقلىشىش پەقەت گۇرۇپپا ئەزالىرى بىلەنلا رۇخسەت قىلىنىدۇ",
    "Sharing %s failed, because this item is already shared with the account %s" : "%s نى ئورتاقلىشىش مەغلۇب بولدى ، چۈنكى بۇ تۈر ئاللىبۇرۇن %s ھېساباتى بىلەن ئورتاقلاشتى",
    "Group sharing is now allowed" : "ھازىر گۇرۇپپا ئورتاقلىشىشقا رۇخسەت قىلىندى",
    "Sharing is only allowed within your own groups" : "ئورتاقلىشىش پەقەت ئۆز گۇرۇپپىڭىزدىلا رۇخسەت قىلىنىدۇ",
    "Path is already shared with this group" : "يول ئاللىقاچان بۇ گۇرۇپپا بىلەن ئورتاقلاشتى",
    "Link sharing is not allowed" : "ئۇلىنىشنى ئورتاقلىشىشقا بولمايدۇ",
    "Public upload is not allowed" : "ئاممىۋى يوللاشقا بولمايدۇ",
    "You cannot share a folder that contains other shares" : "باشقا ئورتاقلىشىشلارنى ئۆز ئىچىگە ئالغان قىسقۇچنى ئورتاقلىشالمايسىز",
    "Sharing is disabled" : "ئورتاقلىشىش چەكلەنگەن",
    "Sharing is disabled for you" : "ئورتاقلىشىش سىز ئۈچۈن چەكلەنگەن",
    "Cannot share with the share owner" : "پاي ئىگىسى بىلەن ئورتاقلىشالمايدۇ",
    "Share does not have a full ID" : "ھەمبەھىرلەشنىڭ تولۇق كىملىكى يوق",
    "Cannot change share type" : "ھەمبەھىر تىپىنى ئۆزگەرتەلمەيدۇ",
    "Can only update recipient on user shares" : "ئىشلەتكۈچى ھەمبەھىرلىرىدىلا قوبۇللىغۇچنى يېڭىلىيالايدۇ",
    "Cannot enable sending the password by Talk with an empty password" : "قۇرۇق پارول بىلەن پاراڭلىشىش ئارقىلىق پارول ئەۋەتىشنى قوزغىتالمايدۇ",
    "Cannot enable sending the password by Talk without setting a new password" : "يېڭى پارول قويماي پاراڭ ئارقىلىق پارول ئەۋەتىشنى قوزغىتالمايدۇ",
    "Cannot disable sending the password by Talk without setting a new password" : "يېڭى پارول تەڭشىمەي پاراڭلىشىش ئارقىلىق پارول ئەۋەتىشنى چەكلىيەلمەيدۇ",
    "Share provider does not support accepting" : "ھەمبەھىر تەمىنلىگۈچى قوبۇل قىلىشنى قوللىمايدۇ",
    "Cannot change target of link share" : "ئۇلىنىش ئورتاقلىشىش نىشانىنى ئۆزگەرتەلمەيدۇ",
    "Invalid share recipient" : "ئىناۋەتسىز",
    "Group \"%s\" does not exist" : "گۇرۇپپا \"%s\" مەۋجۇت ئەمەس",
    "The requested share does not exist anymore" : "تەلەپ قىلىنغان ئۈلۈش ئەمدى مەۋجۇت ئەمەس",
    "The requested share comes from a disabled user" : "تەلەپ قىلىنغان ئۈلۈش چەكلەنگەن ئىشلەتكۈچىدىن كېلىدۇ",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "ئىشلەتكۈچى چەكلىمىسىگە يەتكەنلىكى ئۈچۈن ئىشلەتكۈچى قۇرۇلمىغان. تەپسىلاتىنى بىلىش ئۈچۈن ئۇقتۇرۇشلىرىڭىزنى تەكشۈرۈڭ.",
    "Could not find category \"%s\"" : "\"%s\" تۈرىنى تاپالمىدى",
    "Input text" : "تېكىست كىرگۈزۈڭ",
    "The input text" : "كىرگۈزۈش تېكىستى",
    "Sunday" : "يەكشەنبە",
    "Monday" : "دۈشەنبە",
    "Tuesday" : "سەيشەنبە",
    "Wednesday" : "چارشەنبە",
    "Thursday" : "پەيشەنبە",
    "Friday" : "جۈمە",
    "Saturday" : "شەنبە",
    "Sun." : "يەك",
    "Mon." : "دۈش",
    "Tue." : "سەي",
    "Wed." : "چار",
    "Thu." : "پەي",
    "Fri." : "جۈم",
    "Sat." : "شەن",
    "Su" : "يە",
    "Mo" : "دۈ",
    "Tu" : "سە",
    "We" : "چا",
    "Th" : "پە",
    "Fr" : "جۈ",
    "Sa" : "شە",
    "January" : "قەھرىتان",
    "February" : "ھۇت",
    "March" : "نەۋرۇز",
    "April" : "ئۇمۇت",
    "May" : "باھار",
    "June" : "سەپەر",
    "July" : "چىللە",
    "August" : "تومۇز",
    "September" : "مىزان",
    "October" : "ئوغۇز",
    "November" : "ئوغلاق",
    "December" : "كۆنەك",
    "Jan." : "قەھرىتان",
    "Feb." : "ھۇت",
    "Mar." : "نەۋرۇز",
    "Apr." : "ئۇمۇت",
    "May." : "باھار",
    "Jun." : "سەپەر",
    "Jul." : "چىللە",
    "Aug." : "تومۇز",
    "Sep." : "مىزان",
    "Oct." : "ئوغۇز",
    "Nov." : "ئوغلاق",
    "Dec." : "كۆنەك",
    "A valid password must be provided" : "چوقۇم ئىناۋەتلىك ئىم تەمىنلەش كېرەك",
    "The Login is already being used" : "كىرىش ئاللىقاچان ئىشلىتىلىۋاتىدۇ",
    "Could not create account" : "ھېسابات قۇرالمىدى",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "كىرىشتە پەقەت تۆۋەندىكى ھەرپلەرلا رۇخسەت قىلىنىدۇ: \"a-z\", \"A-Z\", \"0-9\", بوشلۇق ۋە \"_. @ - '\"",
    "A valid Login must be provided" : "ئىناۋەتلىك كىرىش تەمىنلىنىشى كېرەك",
    "Login contains whitespace at the beginning or at the end" : "كىرىشنىڭ بېشىدا ياكى ئاخىرىدا ئاق بوشلۇق بار",
    "Login must not consist of dots only" : "كىرىش پەقەت چېكىتلەردىن تەركىب تاپقان بولۇشى كېرەك",
    "Username is too long" : "ئىشلەتكۈچى نامى بەك ئۇزۇن",
    "Login is invalid because files already exist for this user" : "كىرىش ئىناۋەتسىز ، چۈنكى بۇ ئىشلەتكۈچى ئۈچۈن ھۆججەتلەر بار",
    "Account disabled" : "ھېسابات چەكلەنگەن",
    "Login canceled by app" : "ئەپ ئارقىلىق كىرىش ئەمەلدىن قالدۇرۇلدى",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "تۆۋەندىكى تايىنىشلار ئەمەلگە ئاشمىغاچقا «%1$s» نى قاچىلىغىلى بولمايدۇ:%2$s",
    "a safe home for all your data" : "بارلىق سانلىق مەلۇماتلىرىڭىز ئۈچۈن بىخەتەر ئۆي",
    "Application is not enabled" : "ئىلتىماس قوزغىتىلمىغان",
    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى",
    "Token expired. Please reload page." : "توكەننىڭ ۋاقتى توشتى. بەتنى قايتا يۈكلەڭ.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "ساندان قوزغاتقۇسى (sqlite, mysql ياكى postgresql) ئورنىتىلمىدى.",
    "Cannot write into \"config\" directory." : "\"Config\" مۇندەرىجىسىگە يازغىلى بولمايدۇ.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "بۇنى ئادەتتە تور مۇلازىمېتىرىغا مۇندەرىجە مۇندەرىجىسىگە يېزىش ھوقۇقى بېرىش ئارقىلىق ئوڭشىغىلى بولىدۇ. %s گە قاراڭ",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "ياكى ، config.php ھۆججىتىنى پەقەت ئوقۇشنىلا ئويلىسىڭىز ، ئۇنىڭدا «config_is_read_only» تاللانمىسىنى توغرىلاڭ. %s گە قاراڭ",
    "Cannot create \"data\" directory." : "«سانلىق مەلۇمات» مۇندەرىجىسىنى قۇرغىلى بولمايدۇ.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "بۇنى ئادەتتە تور مۇلازىمېتىرىغا يىلتىز مۇندەرىجىسىگە يېزىش ھوقۇقى بېرىش ئارقىلىق ئوڭشىغىلى بولىدۇ. %s گە قاراڭ",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "ئىجازەتنامە ئادەتتە تور مۇلازىمېتىرىغا يىلتىز مۇندەرىجىسىگە يېزىش ھوقۇقى بېرىش ئارقىلىق ئوڭشىلىدۇ. %s گە قاراڭ.",
    "Your data directory is not writable." : "سانلىق مەلۇمات مۇندەرىجىسىڭىزنى يازغىلى بولمايدۇ.",
    "Setting locale to %s failed." : "يەرلىك ئورۇننى %s قىلىپ تەڭشەش مەغلۇب بولدى.",
    "Please install one of these locales on your system and restart your web server." : "سىستېمىڭىزغا بۇ يەرلىك ئورۇندىن بىرنى قاچىلاپ تور مۇلازىمېتىرىڭىزنى قايتا قوزغىتىڭ.",
    "PHP module %s not installed." : "PHP مودۇلى %s ئورنىتىلمىدى.",
    "Please ask your server administrator to install the module." : "مۇلازىمېتىر باشقۇرغۇچىدىن مودۇل ئورنىتىشنى تەلەپ قىلىڭ.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP تەڭشىكى \"%s\" نى \"%s\" قىلىپ تەڭشىيەلمىدى.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Php.ini دىكى بۇ تەڭشەكنى تەڭشىسىڭىز Nextcloud نى قايتا ئىجرا قىلىدۇ",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ئېنىق قىلىپ قۇر ھۆججەتلىرىنى توسۇش ئۈچۈن قۇرۇلدى. بۇنداق بولغاندا بىر قانچە يادرولۇق ئەپلەرنى زىيارەت قىلغىلى بولمايدۇ.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "بۇ بەلكىم Zend OPcache ياكى eAccelerator غا ئوخشاش غەملەك / تېزلەتكۈچتىن كېلىپ چىققان بولۇشى مۇمكىن.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP مودۇلى ئورنىتىلدى ، ئەمما ئۇلار يەنىلا يوقاپ كەتتىمۇ؟",
    "Please ask your server administrator to restart the web server." : "مۇلازىمېتىر باشقۇرغۇچىڭىزدىن تور مۇلازىمېتىرىنى قايتا قوزغىتىشنى تەلەپ قىلىڭ.",
    "The required %s config variable is not configured in the config.php file." : "لازىملىق %s ئۆزگەرگۈچى مىقدار config.php ھۆججىتىدە سەپلەنمىگەن.",
    "Please ask your server administrator to check the Nextcloud configuration." : "مۇلازىمېتىر باشقۇرغۇچىڭىزنىڭ Nextcloud سەپلىمىسىنى تەكشۈرۈشىنى سوراڭ.",
    "Your data directory is readable by other people." : "سانلىق مەلۇمات مۇندەرىجىسىڭىزنى باشقا كىشىلەر ئوقۇيالايدۇ.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "ئىجازەتنامىنى 0770 غا ئۆزگەرتىڭ ، مۇندەرىجىنى باشقا كىشىلەر تىزىپ قويمايدۇ.",
    "Your data directory must be an absolute path." : "سانلىق مەلۇمات مۇندەرىجىسىڭىز چوقۇم مۇتلەق يول بولۇشى كېرەك.",
    "Check the value of \"datadirectory\" in your configuration." : "سەپلىمىسىڭىزدىكى «datadirectory» نىڭ قىممىتىنى تەكشۈرۈڭ.",
    "Your data directory is invalid." : "سانلىق مەلۇمات مۇندەرىجىسى ئىناۋەتسىز.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "سانلىق مەلۇمات مۇندەرىجىسىنىڭ يىلتىزىدا «%1$s» دەپ ئاتىلىدىغان ھۆججەتنىڭ بارلىقىغا كاپالەتلىك قىلىڭ. ئۇنىڭدا مەزمۇن بولۇشى كېرەك: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "ھەرىكەت \"%s\" قوللىمايدۇ ياكى ئىجرا قىلىنمايدۇ.",
    "Authentication failed, wrong token or provider ID given" : "دەلىللەش مەغلۇپ بولدى ، خاتا بەلگە ياكى تەمىنلىگۈچى كىملىكى بېرىلگەن",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "تەلەپنى ئورۇنداش ئۈچۈن پارامېتىرلار يوقاپ كەتتى. يوقاپ كەتكەن پارامېتىرلار: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID %1$s نى بۇلۇت فېدېراتسىيە تەمىنلىگۈچى تەرىپىدىن ئىشلىتىلگەن \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "كىملىك بىلەن بۇلۇت بىرلەشمىسى تەمىنلىگۈچى: \"%s\" مەۋجۇت ئەمەس.",
    "Could not obtain lock type %d on \"%s\"." : "\"%s\" دىكى %d قۇلۇپ تىپىغا ئېرىشەلمىدى.",
    "Storage unauthorized. %s" : "ساقلاشقا رۇخسەتسىز. %s",
    "Storage incomplete configuration. %s" : "ساقلاش تولۇق ئەمەس. %s",
    "Storage connection error. %s" : "ساقلاش ئۇلىنىش خاتالىقى. %s",
    "Storage is temporarily not available" : "ساقلاش ۋاقتىنچە ئىشلەتكىلى بولمايدۇ",
    "Storage connection timeout. %s" : "ساقلاش ئۇلىنىش ۋاقتى. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "بۇ تەكشۈرۈشنىڭ ئىجرا قىلىنىشى ئۈچۈن تور مۇلازىمېتىرىڭىزنىڭ ئۆزىگە ئۇلىنالايدىغانلىقىغا كاپالەتلىك قىلىشىڭىز كېرەك. شۇڭلاشقا ئۇ چوقۇم كەم دېگەندە ئۇنىڭ «ئىشەنچلىك_ دائىرە» ياكى «overrite.cli.url» دىن بىرنى ھەل قىلالايدىغان ۋە ئۇلىيالايدىغان بولۇشى كېرەك. بۇ مەغلۇبىيەت بەلكىم مۇلازىمېتىر تەرەپتىكى DNS ماسلاشماسلىق ياكى سىرتقا چىقىپ كېتىشتىن مۇداپىئەلىنىش قائىدىسىنىڭ نەتىجىسى بولۇشى مۇمكىن.",
    "Analyze images" : "رەسىملەرنى تەھلىل قىلىڭ",
    "Ask a question about the given images." : "بېرىلگەن رەسىملەر توغرىسىدا سوئال سوراڭ.",
    "Images" : "سۈرەتلەر",
    "Images to ask a question about" : "سوئال سوراشقا بولىدىغان رەسىملەر",
    "Question" : "سوئال",
    "What to ask about the images." : "رەسىملەر ھەققىدە نېمىلەرنى سورىشىڭىز كېرەك.",
    "Generated response" : "ھاسىل قىلىنغان جاۋاب",
    "The answer to the question" : "سوئالغا جاۋاب بېرىڭ",
    "Audio chat" : "ئاۋازلىق پاراڭ",
    "Voice chat with the assistant" : "ياردەمچى بىلەن ئاۋازلىق پاراڭلىشىش",
    "System prompt" : "سىستېما ئەسكەرتمىسى",
    "Define rules and assumptions that the assistant should follow during the conversation." : "ياردەمچى سۆھبەت جەريانىدا ئەمەل قىلىشقا تېگىشلىك قائىدە ۋە پەرەزلەرگە ئېنىقلىما بېرىڭ.",
    "Chat voice message" : "ئاۋازلىق پاراڭ ئۇچۇرى",
    "Describe a task that you want the assistant to do or ask a question." : "ياردەمچىنىڭ قىلىشىنى ئۈمىد قىلغان ۋەزىپىڭىزنى تەسۋىرلەڭ ياكى سوئال سوراڭ.",
    "Chat history" : "پاراڭ تارىخى",
    "The history of chat messages before the current message, starting with a message by the user." : "ئىشلەتكۈچىنىڭ ئۇچۇرىدىن باشلاپ، نۆۋەتتىكى ئۇچۇردىن بۇرۇنقى چات ئۇچۇرلىرىنىڭ تارىخى.",
    "Input transcript" : "كىرگۈزۈش تېكىستى",
    "Transcription of the audio input" : "ئاۋاز كىرىشىنىڭ ترانسكرىپسىيەسى",
    "Response voice message" : "جاۋاب ئاۋازلىق ئۇچۇر",
    "The generated voice response as part of the conversation" : "سۆھبەتنىڭ بىر قىسمى سۈپىتىدە ھاسىل قىلىنغان ئاۋازلىق جاۋاب",
    "Output transcript" : "چىقىرىش تېكىستى",
    "Transcription of the audio output" : "ئاۋاز چىقىرىشنىڭ كۆچۈرۈلۈشى",
    "Transcribe audio" : "ئاۋازنى كۆچۈرۈڭ",
    "Transcribe the things said in an audio" : "ئاۋازدا دېيىلگەن ئىشلارنى خاتىرىلەڭ",
    "Audio input" : "ئاۋاز كىرگۈزۈش",
    "The audio to transcribe" : "كۆچۈرمەكچى بولغان ئاۋاز",
    "Transcription" : "ترانسكرىپسىيە",
    "The transcribed text" : "كۆچۈرۈلگەن تېكىست",
    "Chat by voice with an agent" : "ئاگېنت بىلەن ئاۋازلىق سۆھبەتلەش",
    "Describe a task that you want the agent to do or ask a question." : "ۋاكالەتچىنىڭ قىلىشىنى ئۈمىد قىلغان ۋەزىپىڭىزنى تەسۋىرلەڭ ياكى سوئال سوراڭ.",
    "Confirmation" : "جەزملەشتۈرۈش",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "ئىلگىرى تەلەپ قىلىنغان ھەرىكەتلەرنى جەزملەشتۈرۈش كېرەكمۇ يوق: رەت قىلىش ئۈچۈن 0، جەزملەشتۈرۈش ئۈچۈن 1.",
    "Conversation token" : "سۆھبەت بەلگىسى",
    "A token representing the conversation." : "سۆھبەتنى ئىپادىلەيدىغان بەلگە.",
    "The new conversation token" : "يېڭى سۆھبەت بەلگىسى",
    "Send this along with the next interaction." : "بۇنى كېيىنكى ئالاقىلىشىش بىلەن بىللە ئەۋەتىڭ.",
    "Requested actions by the agent" : "ۋاكالەتچى تەلەپ قىلغان ھەرىكەتلەر",
    "Actions that the agent would like to carry out in JSON format." : "ئاگېنتنىڭ JSON فورماتىدا ئېلىپ بارماقچى بولغان ھەرىكەتلىرى.",
    "Chat with an agent" : "بىر خادىم بىلەن پاراڭلىشىش",
    "Chat message" : "پاراڭ ئۇچۇرى",
    "A chat message to send to the agent." : "خادىمغا ئەۋەتىلدىغان بىر ئۇچۇر",
    "The response from the chat model." : "پاراڭ مودىلىدىن كەلگەن ئىنكاس",
    "Context write" : "مەزمۇن يېزىش",
    "Writes text in a given style based on the provided source material." : "تەمىنلەنگەن مەنبە ماتېرىيالىغا ئاساسەن بېرىلگەن ئۇسلۇبتا تېكىست يازىدۇ.",
    "Writing style" : "يېزىش ئۇسلۇبى",
    "Demonstrate a writing style that you would like to immitate" : "تەقلىد قىلماقچى بولغان يېزىقچىلىق ئۇسلۇبىنى نامايان قىلىڭ",
    "Source material" : "مەنبە ماتېرىيالى",
    "The content that would like to be rewritten in the new writing style" : "يېڭى يېزىقچىلىق ئۇسلۇبىدا قايتا يازماقچى بولغان مەزمۇن",
    "Generated text" : "ھاسىل قىلىنغان تېكىست",
    "The generated text with content from the source material in the given style" : "ھاسىل قىلىنغان تېكىست بېرىلگەن ئۇسلۇبتىكى مەنبە ماتېرىيالدىن كەلگەن مەزمۇن",
    "Emoji generator" : "Emoji ياسىغۇچ",
    "Takes text and generates a representative emoji for it." : "تېكىستنى ئېلىپ ، ئۇنىڭغا ۋەكىللىك emoji ھاسىل قىلىدۇ.",
    "The text to generate an emoji for" : "ئۈچۈن emoji ھاسىل قىلىدىغان تېكىست",
    "Generated emoji" : "ھاسىل قىلىنغان emoji",
    "The generated emoji based on the input text" : "كىرگۈزۈلگەن تېكىستنى ئاساس قىلغان ھاسىل قىلىنغان emoji",
    "Optical character recognition" : "ئوپتىكىلىق خاراكتېر تونۇش",
    "Extract text from files like images or PDFs" : "PDF ياكى سۈرەتتەك ھۆججەتلەردىن تېكىستنى چىقار",
    "Input files" : "كىرگۈزگۈچى ھۆججەتلەر",
    "The files to extract text from" : "تېكىست چىقىرۋالدىغان ھۆججەتلەر",
    "Output texts" : "نەتىنجە تېكىستلەر",
    "The texts that were extracted from the files" : "ھۆججەتلەردىن چىقىرۋېلىندىغان تېكىستلەر",
    "Generate image" : "رەسىم ھاسىل قىلىش",
    "Generate an image from a text prompt" : "تېكىست ئەسكەرتمىسىدىن رەسىم ھاسىل قىلىڭ",
    "Prompt" : "تېز",
    "Describe the image you want to generate" : "ھاسىل قىلماقچى بولغان رەسىمنى تەسۋىرلەڭ",
    "Number of images" : "رەسىم سانى",
    "How many images to generate" : "قانچە رەسىم ھاسىل قىلىش",
    "Output images" : "چىقىرىلغان رەسىملەر",
    "The generated images" : "ھاسىل قىلىنغان رەسىملەر",
    "Generate speech" : "ئاۋاز ھاسىل قىلىش",
    "Generate speech from a transcript" : "تېكىستتىن سۆز ھاسىل قىلىش",
    "Write transcript that you want the assistant to generate speech from" : "ياردەمچىنىڭ سۆز ھاسىل قىلىشىنى ئۈمىد قىلىدىغان تېكىست يېزىڭ",
    "Output speech" : "چىقارغان ئاۋاز",
    "The generated speech" : "ھاسىل قىلغان ئاۋاز",
    "Free text to text prompt" : "تېكىست ئەسكەرتىشكە ھەقسىز تېكىست",
    "Runs an arbitrary prompt through a language model that returns a reply" : "جاۋاب قايتۇرىدىغان تىل مودېلى ئارقىلىق خالىغانچە ئىجرا قىلىدۇ",
    "Describe a task that you want the assistant to do or ask a question" : "ياردەمچى قىلماقچى بولغان ياكى سوئال سورىماقچى بولغان ۋەزىپىنى تەسۋىرلەڭ",
    "Generated reply" : "جاۋاب ھاسىل قىلىندى",
    "The generated text from the assistant" : "ياردەمچىدىن ھاسىل قىلىنغان تېكىست",
    "Change Tone" : "تۈسىنى ئۆزگەرت",
    "Change the tone of a piece of text." : "بىر پارچە تىكىستنىڭ تۈسىنى ئۆزگەرت",
    "Write a text that you want the assistant to rewrite in another tone." : "ياردەمچىنىڭ باشقا ئاھاڭدا قايتا يېزىشىنى ئۈمىد قىلىدىغان تېكىست يېزىڭ.",
    "Desired tone" : "خالايدىغان تون",
    "In which tone should your text be rewritten?" : "سىزنىڭ تېكستىڭىز قايسى توندا چىقسۇن؟",
    "The rewritten text in the desired tone, written by the assistant:" : "سىز خالايدىغان توندا چىققان، ياردەمچى يازغان تېكىست:",
    "Chat" : "پاراڭ",
    "Chat with the assistant" : "ياردەمچى بىلەن پاراڭلىشىڭ",
    "The history of chat messages before the current message, starting with a message by the user" : "نۆۋەتتىكى ئۇچۇردىن بۇرۇنقى پاراڭلىشىش تارىخى ، ئىشلەتكۈچىنىڭ ئۇچۇرىدىن باشلىنىدۇ",
    "Response message" : "جاۋاب ئۇچۇرى",
    "The generated response as part of the conversation" : "ھاسىل قىلىنغان جاۋاب سۆھبەتنىڭ بىر قىسمى",
    "Chat with tools" : "قوراللار بىلەن پاراڭلاش",
    "Chat with the language model with tool calling support." : "قورال چاقىرىش قوللىشى ئارقىلىق تىل مودېلى بىلەن پاراڭلىشىڭ.",
    "Tool message" : "قورال ئۇچۇرى",
    "The result of tool calls in the last interaction" : "ئەڭ ئاخىرقى ئۆز-ئارا تەسىر كۆرسىتىشتىكى قورال چاقىرىشلىرىنىڭ نەتىجىسى",
    "Available tools" : "مەۋجۇت قوراللار",
    "The available tools in JSON format" : "JSON فورماتىدىكى مەۋجۇت قوراللار",
    "The response from the chat model" : "پاراڭ مودىلىنىڭ ئىنكاسى",
    "Tool calls" : "قورال چاقىرىش",
    "Tools call instructions from the model in JSON format" : "قوراللار مودېلدىن JSON فورماتىدا كۆرسەتمىلەرنى چاقىرىدۇ",
    "Formalize text" : "تېكىستنى شەكىللەندۈرۈش",
    "Takes a text and makes it sound more formal" : "بىر تېكىستنى ئېلىپ ، ئۇنى تېخىمۇ رەسمىي ئاڭلايدۇ",
    "Write a text that you want the assistant to formalize" : "ياردەمچىسىنىڭ رەسمىيلىشىشىنى ئۈمىد قىلىدىغان تېكىست يېزىڭ",
    "Formalized text" : "رەسمىيلەشتۈرۈلگەن تېكىست",
    "The formalized text" : "رەسمىيلەشتۈرۈلگەن تېكىست",
    "Generate a headline" : "ماۋزۇ ھاسىل قىلىڭ",
    "Generates a possible headline for a text." : "تېكىست ئۈچۈن مۇمكىن بولغان ماۋزۇ ھاسىل قىلىدۇ.",
    "Original text" : "ئەسلى تېكىست",
    "The original text to generate a headline for" : "ماۋزۇ ھاسىل قىلىدىغان ئەسلى تېكىست",
    "The generated headline" : "ھاسىل قىلىنغان ماۋزۇ",
    "Proofread" : "كوررېكتورلۇق",
    "Proofreads a text and lists corrections" : "تېكىستنى تەكشۈرۈپ، تۈزىتىشلەرنى تىزىپ چىقىدۇ",
    "Text" : "تېكىست",
    "The text to proofread" : "تەكشۈرۈلىدىغان تېكىست",
    "Corrections" : "تۈزىتىش",
    "The corrections that should be made in your text" : "تېكىستىڭىزگە قىلىندىغان تۈزۈتىشلەر",
    "Reformulate text" : "تېكىستنى ئىسلاھ قىلىش",
    "Takes a text and reformulates it" : "بىر تېكىستنى ئېلىپ ئۇنى ئىسلاھ قىلىدۇ",
    "Write a text that you want the assistant to reformulate" : "ياردەمچى ئىسلاھ قىلماقچى بولغان تېكىستنى يېزىڭ",
    "Reformulated text" : "ئۆزگەرتىلگەن تېكىست",
    "The reformulated text, written by the assistant" : "ياردەمچى يازغان ئىسلاھ قىلىنغان تېكىست",
    "Simplify text" : "تېكىستنى ئاددىيلاشتۇرۇڭ",
    "Takes a text and simplifies it" : "تېكىستنى ئېلىپ ئاددىيلاشتۇرىدۇ",
    "Write a text that you want the assistant to simplify" : "ياردەمچى ئاددىيلاشتۇرماقچى بولغان تېكىستنى يېزىڭ",
    "Simplified text" : "ئاددىيلاشتۇرۇلغان تېكىست",
    "The simplified text" : "ئاددىيلاشتۇرۇلغان تېكىست",
    "Summarize" : "خۇلاسە",
    "Summarizes a text" : "بىر تېكىستنى خۇلاسىلىدى",
    "The original text to summarize" : "خۇلاسە قىلىدىغان ئەسلى تېكىست",
    "Summary" : "خۇلاسە",
    "The generated summary" : "ھاسىل قىلىنغان خۇلاسە",
    "Extract topics" : "تېمىنى چىقىرىڭ",
    "Extracts topics from a text and outputs them separated by commas" : "تېمىدىن تېكىستنى چىقىرىپ پەش ئارقىلىق ئايرىپ چىقىدۇ",
    "The original text to extract topics from" : "تېمىنى چىقىرىش ئۈچۈن ئەسلى تېكىست",
    "Topics" : "تېما",
    "The list of extracted topics" : "ئېلىنغان تېمىلارنىڭ تىزىملىكى",
    "Translate" : "تەرجىمە",
    "Translate text from one language to another" : "تېكىستنى بىر تىلدىن يەنە بىر تىلغا تەرجىمە قىلىڭ",
    "Origin text" : "ئەسلى تېكىست",
    "The text to translate" : "تەرجىمە قىلىدىغان تېكىست",
    "Origin language" : "ئەسلى تىل",
    "The language of the origin text" : "ئەسلى تېكىستنىڭ تىلى",
    "Target language" : "نىشانلىق تىل",
    "The desired language to translate the origin text in" : "ئەسلى تېكىستنى تەرجىمە قىلماقچى بولغان تىل",
    "Result" : "نەتىجىدە",
    "The translated text" : "تەرجىمە قىلىنغان تېكىست",
    "Free prompt" : "ھەقسىز ئەسكەرتىش",
    "Runs an arbitrary prompt through the language model." : "تىل مودېلى ئارقىلىق خالىغانچە ئىجرا قىلىدۇ.",
    "Generate headline" : "ماۋزۇ ھاسىل قىلىڭ",
    "Summarizes text by reducing its length without losing key information." : "ئاچقۇچلۇق ئۇچۇرلارنى يوقىتىپ قويماي ئۇزۇنلۇقىنى قىسقارتىش ئارقىلىق تېكىستنى خۇلاسىلەيدۇ.",
    "Extracts topics from a text and outputs them separated by commas." : "تېكىستتىن تېمىنى چىقىرىپ ، پەش ئارقىلىق ئايرىلىدۇ.",
    "Organisation" : "تەشكىلات",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X قوللىمايدۇ، %s بۇ سۇپادا نورمال ئىشلىمەيدۇ. ئۇنى ئۆزىڭىز ئىشلىتىڭ!",
    "Login is too long" : "كىرىش بەك ئۇزۇن",
    "Cannot write into \"apps\" directory." : "«ئەپلەر» مۇندەرىجىسىگە يازغىلى بولمايدۇ.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "بۇنى ئادەتتە تور مۇلازىمېتىرىغا پروگرامما مۇندەرىجىسىگە زىيارەت قىلىش ھوقۇقى ياكى سەپلىمە ھۆججەتتىكى App دۇكىنىنى چەكلەش ئارقىلىق ئوڭشىغىلى بولىدۇ.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code> mbstring.func_overload </code> مۆلچەردىكى قىممەت <code> %s </code> نىڭ ئورنىغا <code>0 </code> قىلىپ تەڭشەلدى.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "بۇ مەسىلىنى ھەل قىلىش ئۈچۈن php.ini دىكى <code> mbstring.func_overload </code> نى <code> 0 </code> قىلىپ تەڭشەڭ."
},
"nplurals=2; plural=(n != 1);");
